@@ -72,7 +72,6 @@ AVAILABLE FEATURES IN THE LIBRARY:
 
 # ignore __pycache__ from forming inside the library directory.
 import sys
-from tokenize import Number
 sys.dont_write_bytecode = True
 
 # meta data imports from the vandal library.
@@ -89,32 +88,13 @@ from vandal.misc._meta import (
 )
 
 # imports plugins.
-from vandal.plugins.metaclass import Meta
-from vandal.plugins.types import (
-    VandalType,
-    IntegerType,
-    FloatType,
-    NumberType,
-    ReturnType,
-    PrintType,
-    GraphType,
-    StringType,
-    ListType,
-    TupleType,
-    DictionaryType,
-    BooleanType,
-    NumberVector,
-    StringVector,
-    StringDictionary,
-    DictionaryVector,
-    NumberVectorAlike,
-    NumberArrayAlike,
-    AnyArrayAlike,
-    AnyVectorAlike,
-)
+from logistics.plugins.metaclass import Meta
+
+# imports all data types.
+from logistics.plugins.types import *
 
 # available types.
-__types__ = [
+types = [
     VandalType,
     IntegerType,
     FloatType,
@@ -127,6 +107,8 @@ __types__ = [
     TupleType,
     DictionaryType,
     BooleanType,
+    FilePathType,
+    SpecialType,
     NumberVector,
     StringVector,
     StringDictionary,
@@ -135,6 +117,12 @@ __types__ = [
     NumberArrayAlike,
     AnyArrayAlike,
     AnyVectorAlike,
+    AnyType,
+]
+
+# metaclass.
+metaclass = [
+    'Meta',
 ]
 
 # object and module imports.
@@ -164,23 +152,27 @@ from vandal.hub.toolkit import (
     save_to,
 )
 
+# colorama imports.
+from colorama import Fore, init
+
 # all relevant contents.
 __all__ = [
-    random_value,
-    random_pool,
-    split_values,
-    join_values,
-    replace_values,
-    list_sort,
-    index_sort,
-    auto_sort,
-    create_password,
-    file_handler,
-    save_to,
-    toolkit,
-    MonteCarlo,
-    MCapp,
-    EOQ,
-    EOQapp,
-    Dijkstra,
+    'random_value',
+    'random_pool',
+    'split_values',
+    'join_values',
+    'replace_values',
+    'list_sort',
+    'index_sort',
+    'auto_sort',
+    'create_password',
+    'file_handler',
+    'save_to',
+    'toolkit',
+    'MonteCarlo',
+    'MCapp',
+    'EOQ',
+    'EOQapp',
+    'Dijkstra',
+    'Meta',
 ]
