@@ -1,3 +1,9 @@
+# metaclass.
+from logistics.plugins.metaclass import Meta
+
+# imports all data types.
+from logistics.plugins.types import *
+
 # import all relevant contents from the associated module.
 from vandal.objects.montecarlo import (
     MonteCarlo,
@@ -13,9 +19,10 @@ from vandal.objects.dijkstra import Dijkstra
 
 # all relevant contents.
 __all__ = [
-    MonteCarlo,
-    EOQ,
-    Dijkstra,
-    MCapp,
-    EOQapp,
+    'MonteCarlo',
+    'EOQ',
+    'Dijkstra',
+    'MCapp',
+    'EOQapp',
+    'Meta',
 ]
