@@ -1,29 +1,10 @@
 # type hints and annotations.
-from vandal.plugins.metaclass import Meta
-from vandal.plugins.types import (
-    VandalType,
-    IntegerType,
-    FloatType,
-    NumberType,
-    ReturnType,
-    PrintType,
-    GraphType,
-    StringType,
-    ListType,
-    TupleType,
-    DictionaryType,
-    BooleanType,
-    NumberVector,
-    StringVector,
-    StringDictionary,
-    DictionaryVector,
-    NumberVectorAlike,
-    NumberArrayAlike,
-    AnyArrayAlike,
-    AnyVectorAlike,
-)
+from logistics.plugins.metaclass import Meta
 
-# object that contains the required data.
+# imports all data types.
+from logistics.plugins.types import *
+
+# package.
 class Dijkstra:
 
     '''
@@ -73,13 +54,16 @@ class Dijkstra:
         __APPversion__,
     )
 
-    # initial launch.
     def __init__(
         self,
         nodes : DictionaryType = None, 
         origin : StringType = None, 
         destination : StringType = None,
         ) -> ReturnType:
+
+        '''
+        * initial launch.
+        '''
         
         self.nodes = nodes
         self.origin = origin
@@ -87,26 +71,38 @@ class Dijkstra:
         
         return
 
-    # class information.
     def __str__(
         self,
         ) -> StringType:
 
+        '''
+        * class information.
+        '''
+
         return f'Dijkstra defining object that stores the configuration data for finding the path within {self.nodes} from {self.origin} => {self.destination}.'
 
-    # class information.
     def __repr__(
         self,
         ) -> StringType:
 
+        '''
+        * class information.
+        '''
+
         return f'Dijkstra defining object that stores the configuration data for finding the path within {self.nodes} from {self.origin} => {self.destination}.'
 
-    # executes a Dijkstra algorithm route scan on a defined path.
     def execute(
         self,
-        filtered : bool = True,
+        filtered : BooleanType = True,
         ) -> AnyArrayAlike:
 
+        '''
+        * executes a Dijkstra algorithm route scan on a defined path.
+
+        - filtered (True/False) - filters the information about path.
+        # DEFAULT: Dijkstra.execute(filtered : BooleanType = True.)
+        '''
+
         import pandas as pd
         import numpy as np
 
@@ -159,4 +155,4 @@ class Dijkstra:
             final_path = pd.DataFrame(final_path, index = ['Output'])
             final_path = final_path.transpose() 
 
-            return final_path
\ No newline at end of file
+            return final_path
