@@ -4,31 +4,12 @@ from colorama import Fore, init
 init()
 
 # type hints and annotations.
-from vandal.plugins.metaclass import Meta
-from vandal.plugins.types import (
-    VandalType,
-    IntegerType,
-    FloatType,
-    NumberType,
-    ReturnType,
-    PrintType,
-    GraphType,
-    StringType,
-    ListType,
-    TupleType,
-    DictionaryType,
-    BooleanType,
-    NumberVector,
-    StringVector,
-    StringDictionary,
-    DictionaryVector,
-    NumberVectorAlike,
-    NumberArrayAlike,
-    AnyArrayAlike,
-    AnyVectorAlike,
-)
+from logistics.plugins.metaclass import Meta
 
-# object that contains the simulation data.
+# imports all data types.
+from logistics.plugins.types import *
+
+# package.
 class MonteCarlo:
 
     '''
@@ -109,7 +90,6 @@ class MonteCarlo:
         __APPversion__,
     )
 
-    # initial launch.
     def __init__(
         self, 
         list_of_values : NumberVectorAlike = None, 
@@ -119,41 +99,55 @@ class MonteCarlo:
         ref_row : IntegerType = 0,
         ) -> ReturnType:
 
+        '''
+        * initial launch.
+        '''
+
         self.list_of_values = list_of_values
         self.time_seq = time_seq
         self.num_sims = num_sims
         self.ref_col = ref_col
         self.ref_row = ref_row
 
-        import pandas as pd
-
         return 
 
-    # class information.
     def __str__(
         self,
         ) -> StringType:
 
+        '''
+        * class information.
+        '''
+
         return f'Monte Carlo defining object that stores the configuration data for creating {self.num_sims} simulations in a period of {self.time_seq} time measurement units.'
 
-    # class information.
     def __repr__(
         self,
         ) -> StringType:
 
+        '''
+        * class information.
+        '''
+
         return f'Monte Carlo defining object that stores the configuration data for creating {self.num_sims} simulations in a period of {self.time_seq} time measurement units.'
 
-    # executes a Monte Carlo simulation on a defined data set.
     def execute(
         self,
         filtered : BooleanType = True,
         ) -> NumberArrayAlike:
 
+        '''
+        * executes a Monte Carlo simulation on a defined data set.
+
+        - filtered (True/False) - filters the data setup print and warnings.
+        # DEFAULT: MonteCarlo.execute(filtered : BooleanType = True.)
+        '''
+
         if filtered == False:
             print(Fore.GREEN + f'Monte Carlo has been set up for {self.num_sims} simulations in a period of {self.time_seq} time measurement units and executed.' + Fore.RESET)
             print(Fore.RED + 'NOTE: Use data with reasonable standard deviation in order to prevent exponential growth of the function that cannot be plotted properly, recognize such abnormal values by a + sign anywhere in the data executed below.' + Fore.RESET)
         
-        from vandal.hub.toolkit import random_value
+        import numpy as np
         import pandas as pd
 
         # this removes pandas warning of highly fragmented DataFrame for newer pandas versions.
@@ -172,24 +166,18 @@ class MonteCarlo:
         loading = 0
 
         for num_sim in range(self.num_sims):
-            rand_change = random_value(self.list_of_values.pct_change().mean(), self.list_of_values.pct_change().std())
+            rand_change = self.list_of_values.pct_change().std()
             count = 0
             index_array = []
-            index_array += [today_value * (1 + rand_change)]
-
-            if index_array[count] > (index_array[-1] * 3):
-                raise Exception('Variation between data is too big, due to detection of exponentional increase of values or non-sequential data Monte Carlo simulation cannot be executed properly.')
+            index_array += [today_value + (today_value * np.random.normal(0, rand_change))]
 
             for num_day in range(self.time_seq):
-                rand_change = random_value(self.list_of_values.pct_change().mean(), self.list_of_values.pct_change().std())
+                rand_change = self.list_of_values.pct_change().std()
                 if count == self.time_seq:
                     break
-                index_array += [index_array[count] * (1 + rand_change)]
+                index_array += [index_array[count] + (today_value * np.random.normal(0, rand_change))]
                 count += 1
 
-                if index_array[count] > (index_array[-1] * 3):
-                    raise Exception('Variation between data is too big, due to detection of exponentional increase of values or non-sequential data Monte Carlo simulation function cannot be executed properly.')
-
             loading += 1
             print(end = '\r')
             print(loading, 'iterations out of', self.num_sims, 'executed so far', end = '')
@@ -201,19 +189,28 @@ class MonteCarlo:
 
         return data
 
-    # shows the percentage of Monte Carlo simulation value change for every iteration.
     def get_change(
         self,
         ) -> NumberArrayAlike:
 
+        '''
+        * shows the percentage of Monte Carlo simulation value change for every iteration.
+        '''
+
         return self.results.pct_change()
 
-    # calculates the risk of negative values occuring.
     def get_risk(
         self, 
         risk_sims : IntegerType = 5000,
         ) -> NumberType:
 
+        '''
+        * calculates the risk of negative values occuring.
+
+        - risk_sims - number of simulations to run risk evaluation on.
+        # DEFAULT: MonteCarlo.get_risk(risk_sims : IntegerType = 5000.)
+        '''
+
         import random
         import pandas as pd
 
@@ -230,7 +227,6 @@ class MonteCarlo:
         for num_sim in range(risk_sims):
             random_change = random.choice(percent_change)
             index_array = []
-
             index_array += [today_value * (1 + (random_change))]
             data[num_sim] = index_array
 
@@ -238,12 +234,10 @@ class MonteCarlo:
                 if sim < today_value:
                     smaller += [sim]
         NRisk = len(smaller) / num_sim * 100
-
         assert (NRisk < 100), '\nTime sequence and/or number of iterations are too low for the proper risk calculation.'
 
         return str(round(NRisk, 2)) + '%'
 
-    # plots the Monte Carlo simulation on a graph.
     def graph(
         self, 
         graph_title : StringType = 'Monte Carlo simulation', 
@@ -253,6 +247,17 @@ class MonteCarlo:
         perform_block : BooleanType = True,
         ) -> GraphType:
 
+        '''
+        * plots the Monte Carlo simulation on a graph.
+
+        - graph title - sets a graph title.
+        - x_title - sets an x axis title.
+        - y_title - sets and y axis title.
+        - plot_size - sets a size of graph in a tuple (eg. (x,y).)
+        - perform_block (True/False) - customizable wheel to disable block in some IDEs.
+        # DEFAULT: MonteCarlo.graph(graph_title : StringType = 'Monte Carlo simulation', x_title : StringType = 'X axis', y_title : StringType = 'Y axis', plot_size : TupleType = (25,10), perform_block : BooleanType = True.)
+        '''
+
         print(Fore.GREEN + '\nMonteCarlo() plotting initialized.' + Fore.RESET)
         import matplotlib.pyplot as plt
         plt.figure(figsize = plot_size)
@@ -267,10 +272,13 @@ class MonteCarlo:
 
         return
 
-    # shows the statistics of the Monte Carlo simulation.
     def get_stats(
         self,
         ) -> AnyArrayAlike:
+
+        '''
+        * shows the statistics of the Monte Carlo simulation.
+        '''
         
         import numpy as np
         import pandas as pd
@@ -298,7 +306,6 @@ class MonteCarlo:
 
         return stats 
 
-    # plots the histogram of Monte Carlo simulation.
     def hist(
         self, 
         graph_title : StringType = 'Histogram of value frequencies', 
@@ -310,6 +317,19 @@ class MonteCarlo:
         **method : StringType,
         ) -> GraphType:
 
+        '''
+        * plots the histogram of Monte Carlo simulation.
+
+        - graph title - sets a graph title.
+        - x_title - sets an x axis title.
+        - y_title - sets and y axis title.
+        - plot_size - sets a size of graph in a tuple (eg. (x,y).)
+        - perform_block (True/False) - customizable wheel to disable block in some IDEs.
+        - set_bins - sets amount of histogram bins.
+        - **method ('e' - empirical, 'b' - basic)- method of a histogram.
+        # DEFAULT: MonteCarlo.hist(graph_title : StringType = 'Histogram of value frequencies', x_title : StringType = 'X axis', y_title : StringType = 'Y axis', plot_size : TupleType = (25,10), perform_block : BooleanType = True,set_bins : IntegerType = None, **method : StringType.)
+        '''
+
         self.get_stats()
         std_plus = self.mean_value + self.standard_deviation
         std_minus = self.mean_value - self.standard_deviation
@@ -357,12 +377,10 @@ class MonteCarlo:
 def MCapp():
 
     '''
-    
     runs as:
 
-        *IDE: vandal.MCapp()
-        *TERMINAL: python -m vandal -e montecarlo / python -m vandal --entry montecarlo
-        
+        * IDE: vandal.MCapp()
+        * TERMINAL: python -m vandal -e montecarlo / python -m vandal --entry montecarlo
     '''
 
     print(Fore.YELLOW + 'MonteCarlo app is initializing...', Fore.RESET)
@@ -401,7 +419,6 @@ def MCapp():
                 listinput = input('Enter a value: ')
                 listinput = listinput.replace(",", ".")
                 listinput = float(listinput)
-
                 data.append(listinput)
             except:
                 print('')
@@ -423,7 +440,7 @@ def MCapp():
     # simulation parameters and execution.
     simulations = int(input('Enter number of simulations: ') or 100)
     period = int(input('Enter desired period: ') or 50)
-
+    
     MC = MonteCarlo(list_of_values = data, num_sims = simulations, time_seq = period)
     print('')
     executed = MC.execute(filtered = False)
@@ -434,11 +451,9 @@ def MCapp():
 
         if action == 'graph':
             print('')
-
             title = input('Title: ')
             x_axis = input('X axis title:')
             y_axis = input('Y axis title:')
-
             MC.graph(graph_title = title, x_title = x_axis, y_title = y_axis)
 
         if action == 'change':
@@ -446,9 +461,8 @@ def MCapp():
             print('0 | csv')
             print('1 | xlsx')
             print('2 | json')
-
+            
             file_type = input('\nEnter the number or name of file type: ')
-
             output = MC.get_change()
 
             try:
@@ -474,9 +488,7 @@ def MCapp():
 
         if action == 'risk':
             sample = int(input('Number of iterations to measure risk on: ') or 5000)
-
             executed_risk = MC.get_risk(risk_sims = sample)
-
             print(Fore.YELLOW + '\nRisk for this option is' + Fore.RESET, executed_risk[:-1], Fore.YELLOW + '%.' + Fore.RESET)
 
         if action == 'hist' or action == 'histogram':
@@ -506,4 +518,4 @@ def MCapp():
 
 # runs module as an app.
 if __name__ == '__main__':
-    MCapp()
\ No newline at end of file
+    MCapp()
